.. image:: https://img.shields.io/pypi/v/nengo.svg
  :target: https://pypi.python.org/pypi/nengo
  :alt: Latest PyPI version

.. image:: https://img.shields.io/travis/nengo/nengo/master.svg
  :target: https://travis-ci.org/nengo/nengo
  :alt: Travis-CI build status

.. image:: https://ci.appveyor.com/api/projects/status/8ou34p2bgqf2qjqh/branch/master?svg=true
  :target: https://ci.appveyor.com/project/nengo/nengo
  :alt: AppVeyor build status

.. image:: https://img.shields.io/codecov/c/github/nengo/nengo/master.svg
  :target: https://codecov.io/gh/nengo/nengo/branch/master
  :alt: Test coverage


********************************************
Nengo: Large-scale brain modelling in Python
********************************************

.. image:: http://c431376.r76.cf2.rackcdn.com/71388/fninf-07-00048-r2/image_m/fninf-07-00048-g001.jpg
  :alt: An illustration of the three principles of the NEF

Installation
============

Nengo depends on NumPy, and we recommend that you
install NumPy before installing Nengo.
If you're not sure how to do this, we recommend using
`Anaconda <https://store.continuum.io/cshop/anaconda/>`_.

To install Nengo::

    pip install nengo

If you have difficulty installing Nengo or NumPy,
please read the more detailed
`Nengo installation instructions
<https://pythonhosted.org/nengo/getting_started.html#installation>`_ first.

If you'd like to install Nengo from source,
please read the `developer installation instructions
<https://pythonhosted.org/nengo/contributing.html#developer-installation>`_.

Nengo is tested to work on Python 2.7 and 3.4+.

Examples
========

Here are six of
`many examples <https://pythonhosted.org/nengo/examples.html>`_
showing how Nengo enables the creation and simulation of
large-scale neural models in few lines of code.

1. `100 LIF neurons representing a sine wave
   <https://pythonhosted.org/nengo/examples/many_neurons.html>`_
2. `Computing the square across a neural connection
   <https://pythonhosted.org/nengo/examples/squaring.html>`_
3. `Controlled oscillatory dynamics with a recurrent connection
   <https://pythonhosted.org/nengo/examples/controlled_oscillator.html>`_
4. `Learning a communication channel with the PES rule
   <https://pythonhosted.org/nengo/examples/learn_communication_channel.html>`_
5. `Simple question answering with the Semantic Pointer Architecture
   <https://pythonhosted.org/nengo/examples/question.html>`_
6. `A summary of the principles underlying all of these examples
   <https://pythonhosted.org/nengo/examples/nef_summary.html>`_

Documentation
=============

Usage and API documentation can be found at
`<https://pythonhosted.org/nengo/>`_.

Development
===========

Information for current or prospective developers can be found
at `<https://pythonhosted.org/nengo/dev_guide.html>`_.

Getting Help
============

Questions relating to Nengo, whether it's use or it's development, should be
asked on the Nengo forum at `<https://forum.nengo.ai>`_.
